tsseg.algorithms.tscp2 package
==============================

Learns temporal representations by predicting future windows, detects CPD via
representation dissimilarity.

| **Type:** change point detection
| **Supervision:** unsupervised or semi-supervised
| **Requires:** TensorFlow and ``tcn``

**Implementation:** TF reimplementation adapted from original code by Deldari et al.
No licence specified.

**Reference:** Deldari, Smith, Xue & Salim (2021), WWW.

.. automodule:: tsseg.algorithms.tscp2.detector
   :members:
   :show-inheritance:
   :undoc-members:
